# sense-export

> Just a simple button to export data in your Qlik Sense application without displaying them in a table first.

[![Codacy Badge](https://api.codacy.com/project/badge/Grade/8e0674740ec048ab85fc18bbdd85d2bd)](https://www.codacy.com/app/stefan-walther/sense-export?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=stefanwalther/sense-export&amp;utm_campaign=badger)

![sense-export](https://raw.githubusercontent.com/stefanwalther/sense-export/master/docs/images/sense-export.png)

***

## Table of Contents

- [Purpose and Description](#purpose-and-description)
  * [Why?](#why)
  * [Screenshots](#screenshots)
- [Installation & Download](#installation--download)
- [Configuration](#configuration)
  * [Dimensions & Measures](#dimensions--measures)
  * [Button label](#button-label)
  * [Button layout](#button-layout)
  * [Export definition](#export-definition)
  * [Debug](#debug)
- [Compatibility](#compatibility)
- [Known Issues](#known-issues)
- [Related Projects](#related-projects)
- [About](#about)
  * [Change Log](#change-log)
- [Contributing](#contributing)
  * [Using the Project in Dev-Hub](#using-the-project-in-dev-hub)
  * [Author](#author)
  * [License](#license)

_(TOC generated by [verb](https://github.com/verbose/verb) using [markdown-toc](https://github.com/jonschlinkert/markdown-toc))_

***

## Purpose and Description

**sense-export** is a tiny and sweet visualization extension allowing you to **export data without showing the underlying table**.

### Why?

Every object in Qlik Sense provides the export functionality, but sometimes one just wants to provide a download of some data from your data model by putting a tiny little button onto a screen, completely without showing the data first.

### Screenshots

Just a very simple button with some properties to define the layout and the behavior of the export.
See **Configuration** for mor details.

![All properties](https://raw.githubusercontent.com/stefanwalther/sense-export/master/docs/images/all-props.png)

## Installation & Download

1. Download the [latest version](https://github.com/stefanwalther/sense-export/raw/master/build/sense-export_latest.zip) or [any other version](https://github.com/stefanwalther/sense-export/tree/master/build) you want to install.
2. Then install on either _Qlik Sense Desktop_ or _Qlik Sense Server_:

* Qlik Sense Desktop
  - To install, unzip all files and copy the content to the folder folder `"C:\Users\%USERNAME%\Documents\Qlik\Sense\Extensions\sense-navigation"`
* Qlik Sense Server
  - See instructions [how to import an extension on Qlik Sense Server](http://help.qlik.com/sense/2.0/en-US/online/#../Subsystems/ManagementConsole/Content/import-extensions.htm)

**NOTE: Do not use the download button on GitHub to download the entire GitHub repository**, please follow the instructions below! - otherwise you'll run into issues importing the visualization extension on Qlik Sense Enterprise.

## Configuration

### Dimensions & Measures

Define dimensions and measures as you would do for every other extension.
Pro Tip: Enable the debug mode if you want to see the result.

### Button label

* **Label** - Just define the label of the button, defaults to "Export".

![Button label property](https://raw.githubusercontent.com/stefanwalther/sense-export/master/docs/images/prop-label.png)

### Button layout

The possibilities to layout the button should (hopefully) be pretty self-explanatory:

* **Style** - Select on of the predefined styles.
* **Button width** - Define whether the button should take the full width of the object or not.
* **Alignment** - Define the **horizontal** alignment.
* **Icon** - Select one of the provided icons. Defaults to "download"
Pro Tip: Font Awesome icons are used here, go to https://fortawesome.github.io/Font-Awesome/icons/ to get a nice overview of all icons possible.

![Property export definition](https://raw.githubusercontent.com/stefanwalther/sense-export/master/docs/images/prop-export-definition.png)

### Export definition

Define the final output of the export:

* **Format** - Select on of the following values (defaults ot "Open XML (Excel)):
  1. Open XML (Excel),
  2. Comma separated CSV,
  3. Tab separated CSV"
  4. Comma separated CSV - Client Side ([see below](#a-note-on-comma-separated-csv---client-side) for more information)
* **State** - You can define whether your current selection will be considered or not. If this is the desired behavior, select "Possible values", otherwise "All values", then always all data will be exported, regardless the current selections.
* **File name** - Optionally you can define a file name.

![Property export definition](https://raw.githubusercontent.com/stefanwalther/sense-export/master/docs/images/prop-export-definition.png)

#### A note on "Comma separated CSV - Client Side"

This is an experimental feature and will generated the exported file client-side, so in your browser, and not using the QIX Engine to generated the file.
Why? There is a scenario where Qlik Sense Enterprise is configured to provide anonymous access to dashboard. In that case the QIX Engine generates the export files, but QRS does not allow to serve them (this can obviously seen as a bug and is being investigated).

Use this functionality with caution

* Client side generation of export files is much slower
* You might run into issues with larger data-sets

Currently tested only with this setup:

* Qlik Sense 3.2 SR2, SR3
* Chrome, Firefox, IE
* Up to about 100.000 records with 10 columns (... takes quite a while, but works)

### Debug

While working in edit mode it's quite helpful to test the data (which will then be exported in the defined format).
If you enable the debug mode a debug table will be shown to double-check if you you have defined the correct measures and dimensions.

Note:

* The debug table will only be shown in edit mode, even if this settings is activated
* The debug table only shows the first 500 records (for performance reasons). The export will contain all data, though.

![Property debug](https://raw.githubusercontent.com/stefanwalther/sense-export/master/docs/images/prop-debug.png)

## Compatibility

**_sense-export_** is designed to work with Qlik Sense 2.1.1 or higher.
If you use the visualization extension in an older version of Qlik Sense the following message will be shown:

![Unsupported message](https://raw.githubusercontent.com/stefanwalther/sense-export/master/docs/images/unsupported.png)

## Known Issues

There are two known improvements which might be addressed in future versions:

* Vertical alignment of the button is currently now possible.
* Improvement for the mobile view, reserve less space for the export button.
* Would be nice to have some kind of spinner in case of the client export

## Related Projects

Some related projects (Qlik Sense Visualization Extensions) I have recently created:

* [qliksense-extension-tutorial](https://www.npmjs.com/package/qliksense-extension-tutorial): Comprehensive tutorial to start developing Qlik Sense Extensions. | [homepage](https://github.com/stefanwalther/qliksense-extension-tutorial "Comprehensive tutorial to start developing Qlik Sense Extensions.")
* [sense-calendar-heatmap](https://www.npmjs.com/package/sense-calendar-heatmap): Qlik Sense Visualization Extension with a diverging color scale. The values are displayed as colored… [more](https://github.com/stefanwalther/qsCalendarHeatmap) | [homepage](https://github.com/stefanwalther/qsCalendarHeatmap "Qlik Sense Visualization Extension with a diverging color scale. The values are displayed as colored cells per day. Days are arranged into columns by week, then grouped by month and years.")
* [sense-extension-recipes](https://www.npmjs.com/package/sense-extension-recipes): Recipes on working with Qlik Sense Visualization Extensions. | [homepage](https://github.com/stefanwalther/sense-extension-recipes "Recipes on working with Qlik Sense Visualization Extensions.")
* [sense-funnel-chart](https://www.npmjs.com/package/sense-funnel-chart): Funnel Chart for Qlik Sense. | [homepage](https://github.com/stefanwalther/sense-funnel-chart "Funnel Chart for Qlik Sense.")
* [sense-media-box](https://www.npmjs.com/package/sense-media-box): Include web pages, videos, images and much more into your Qlik Sense app. | [homepage](https://github.com/stefanwalther/sense-media-box "Include web pages, videos, images and much more into your Qlik Sense app.")
* [sense-navigation](https://www.npmjs.com/package/sense-navigation): Sense Sheet Navigation + Actions visualization extension for Qlik Sense. | [homepage](https://github.com/stefanwalther/sense-navigation#readme "Sense Sheet Navigation + Actions visualization extension for Qlik Sense.")
* [sense-on-off-switch](https://www.npmjs.com/package/sense-on-off-switch): Set a variable in Qlik Sense to true/false using an on-off switch. | [homepage](https://github.com/stefanwalther/sense-on-off-switch "Set a variable in Qlik Sense to true/false using an on-off switch.")
* [sense-qr-code](https://www.npmjs.com/package/sense-qr-code): QR Code to be embedded into Qlik Sense. | [homepage](https://github.com/stefanwalther/qsQRCode "QR Code to be embedded into Qlik Sense.")
* [sense-range-slider](https://www.npmjs.com/package/sense-range-slider): Slider object for Qlik Sense to manipulate one or two variables. | [homepage](https://github.com/QlikDev/qsRangeSlider "Slider object for Qlik Sense to manipulate one or two variables.")
* [sense-themable-kpi-tile](https://www.npmjs.com/package/sense-themable-kpi-tile): KPI Tile for Qlik Sense with the ability to use themes or to customize background… [more](https://github.com/stefanwalther/sense-themable-kpi-tile) | [homepage](https://github.com/stefanwalther/sense-themable-kpi-tile "KPI Tile for Qlik Sense with the ability to use themes or to customize background color, comparison indicator, etc.")

## About

### Change Log

See [./CHANGELOG.yml](CHANGELOG.yml)

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/stefanwalther/sense-export/issues).
The process for contributing is outlined below:

1. Create a fork of the project
2. Work on whatever bug or feature you wish
3. Create a pull request (PR)

I cannot guarantee that I will merge all PRs but I will evaluate them all.

### Using the Project in Dev-Hub

The default build of **_sense-export_** minifies the JavaScript files and does not contain a [wbfolder.wbl file](http://qliksite.io/tutorials/qliksense-visualization-extensions/part-09/1002-Troubleshooting-FAQ/#what-is-a-wbl-file) (which is just necessary for Dev-Hub).

So if you want to edit the extension or create your own extension based on **_sense-export_** download the [./build/sense-export_dev.zip](https://github.com/stefanwalther/sense-export/raw/master/build/sense-export_dev.zip) file which always contains the latest version + a `wbfolder.wbl` file.

### Author

**Stefan Walther**

* [stefanwalther.io](http://stefanwalther.io)
* [qliksite.io](http://qliksite.io)
* [twitter/waltherstefan](http://twitter.com/waltherstefan)
* [github.com/stefanwalther](http://github.com/stefanwalther)

### License

MIT

***

_This file was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme), v0.6.0, on July 20, 2017._